.. TJPCov documentation master file, created by
   sphinx-quickstart on Wed Dec 21 00:24:39 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to TJPCov's documentation!
==================================

TJPCov is a general covariance calculator interface to be used within LSST DESC.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   example
   autoapi/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
